/*
 * -------------------------------------------------------------------
 * (c) 2001-2003 GIE SESAM-VITALE
 *
 * PROJET   : Services Reglementation et Tarification
 *
 * FICHIER  : srt.h (v5)
 *
 * Declaration des prototypes des fonctions SRT
 * -------------------------------------------------------------------
 */

#ifndef __SRT_H__
#define __SRT_H__

#ifdef __cplusplus
extern "C" {
#endif


    /*
     * Inclusions
     */
#include <stddef.h>
/* Inclure le fichier de dclarations spcifiques systme : win32def.h, macosdef.h, unixdef.h, etc. */


/*
* Declarations des fonctions publiques "standards"
*/

/* Recherche de codes CCAM par mot cle. */
typedef unsigned short (API_ENTRY FARPTR SRT_RechercherParMotCle)
    (const char*    MotCle,
     unsigned long  CadreRecherche,
     void**         ZDonneesSortie,
     size_t*        TailleDonneesSortie);

/* Recherche de codes CCAM par filtre. */
typedef unsigned short (API_ENTRY FARPTR SRT_RechercherParFiltre)
    (const char*    Filtre,
     void**         ZDonneesSortie,
     size_t*        TailleDonneesSortie);

/* Consultation de donnees CCAM. */
typedef unsigned short (API_ENTRY FARPTR SRT_ConsulterDonnee)
    (const char*    Identifiant,
     const char*    DateReference,
     void*          ZDonneesEntree,
     size_t         TailleDonneesEntree,
     void**         ZDonneesSortie,
     size_t*        TailleDonneesSortie);

/* Modification d'un champ mono-occurrent. */
typedef unsigned short (API_ENTRY FARPTR SRT_ModifierDonnee)
    (const char*    Identifiant,
     const char*    DateEffet,
     void*          ZDonneesEntree,
     size_t         TailleDonneesEntree);

/* Annulation d'une modification */
typedef unsigned short (API_ENTRY FARPTR SRT_AnnulerModification)
    (const char*    Identifiant,
     void*          ZDonneesEntree,
     size_t         TailleDonneesEntree);

/* Controle de la validite d'une ou plusieurs donnees. */
typedef unsigned short (API_ENTRY FARPTR SRT_ControlerDonnees)
    (const char*    Identifiant,
     const char*    DateReference,
     void*          ZDonneesEntree,
     size_t         TailleDonneesEntree,
     unsigned char* Resultat);

/* Regle de gestion ou de tarification. */
typedef unsigned short (API_ENTRY FARPTR SRT_AppliquerRegle)
    (const char*    Identifiant,
     void*          ZDonneesEntree,
     size_t         TailleDonneesEntree,
     void**         ZDonneesSortie,
     size_t*        TailleDonneesSortie);

/* Controle complet. */
typedef unsigned short (API_ENTRY FARPTR SRT_ControleComplet)
    (void*          ZDonneesEntree,
     size_t         TailleDonneesEntree,
     void**         ZDonneesSortie,
     size_t*        TailleDonneesSortie);

/* Chargement du referentiel. */
typedef unsigned short (API_ENTRY FARPTR SRT_InitLIB2)(const char* SesamIni);

/* Dechargement du referentiel. */
typedef unsigned short (API_ENTRY FARPTR SRT_TermLIB)(void);

/* Sauvegarde des modifications. */
typedef unsigned short (API_ENTRY FARPTR SRT_SauvegarderReferentiel)(const char* Commentaire);

/* Version du referentiel. */
typedef unsigned short (API_ENTRY FARPTR SRT_LireVersion)
    (void**         ZDonneesSortie,
     size_t*        TailleDonneesSortie);

/* Activation de la trace. */
typedef unsigned short (API_ENTRY FARPTR SRT_InitTrace)
	(const char*    pathConf,
     const char*    ModeOuverture,
     unsigned short Module,
     unsigned char  Niveau);

/* Allocation d'une zone memoire. */
typedef unsigned short (API_ENTRY FARPTR SRT_AllouerZoneMem)
    (void**         Zone,
     size_t         Taille);

/* Allocation d'une zone memoire. */
typedef void (API_ENTRY FARPTR SRT_LibererZoneMem) (void*  Zone);

/*
* Declarations des fonctions publiques "simplifiees"
*/

/* Recherche de codes CCAM par mot cle. */
typedef unsigned short (API_ENTRY FARPTR SRT_RechercherParMotCle_S)
    (const char*    MotCle,
     unsigned long  CadreRecherche,
     unsigned short NumeroSession);

/* Recherche de codes CCAM par filtre. */
typedef unsigned short (API_ENTRY FARPTR SRT_RechercherParFiltre_S)
    (const char*    Filtre,
     unsigned short NumeroSession);

/* Consultation de donnees CCAM. */
typedef unsigned short (API_ENTRY FARPTR SRT_ConsulterDonnee_S)
    (const char*    Identifiant,
     const char*    DateReference,
     unsigned short NumeroSession);

/* Modification d'un champ mono-occurrent. */
typedef unsigned short (API_ENTRY FARPTR SRT_ModifierDonnee_S)
    (const char*    Identifiant,
     const char*    DateEffet,
     unsigned short NumeroSession);

/* Annulation des modifications d'une donnee. */
typedef unsigned short (API_ENTRY FARPTR SRT_AnnulerModification_S)
    (const char*    Identifiant,
     unsigned short NumeroSession);

/* Controle de la validite d'une ou plusieurs donnees. */
typedef unsigned short (API_ENTRY FARPTR SRT_ControlerDonnees_S)
    (const char*    Identifiant,
     const char*    DateReference,
     unsigned short NumeroSession,
     unsigned char* Resultat);

/* Regle de gestion ou de tarification. */
typedef unsigned short (API_ENTRY FARPTR SRT_AppliquerRegle_S)
    (const char*    Identifiant,
     unsigned short NumeroSession);

/* Controle complet. */
typedef unsigned short (API_ENTRY FARPTR SRT_ControleComplet_S)
    (unsigned short NumeroSession);

/* Version du referentiel. */
typedef unsigned short (API_ENTRY FARPTR SRT_LireVersion_S)
    (unsigned short NumeroSession);


#ifdef __cplusplus
}
#endif

#endif
